@@ -160,7 +160,7 @@ class Product(ModelSQL, ModelView):
         cost_values = {}
         context = {}
         trans_context = Transaction().context
-        if 'stock_date_end' in context:
+        if trans_context.get('stock_date_end'):
             context['_datetime'] = trans_context['stock_date_end']
         with Transaction().set_context(context):
             for product in self.browse(ids):
